@@ -1691,6 +1691,7 @@ class Builder(Update):
         audio = self.clVars.Get('cl_builder_audio')
         locale = self.clVars.Get('cl_builder_locale_lang')
         timezone = self.clVars.Get('cl_builder_timezone')
+        clock = self.clVars.Get('install.os_install_clock_type')
         params = ["%s:%s" % (CmdlineParams.Locale, locale),
                   "%s:%s" % (CmdlineParams.Timezone, timezone)]
         resolution = self.clVars.Get('cl_builder_x11_resolution')
@@ -1705,6 +1706,8 @@ class Builder(Update):
                 params.append("%s:%s" % (CmdlineParams.Composite, composite))
         if audio == "alsa":
             params.append("audio:alsa")
+        if clock:
+            params.append("clock:%s"%clock)
         calculate_param = ",".join(params)
         if self.clVars.GetBool('cl_builder_docache_set'):
             return "%s docache" % calculate_param
