@@ -48,7 +48,7 @@ class BuilderLinux(ReadonlyVariable):
             dv = self.Get('cl_builder_linux_datavars')
             if dv:
                 return dv[self.variable]
-        except VariableError:
+        except VariableError as e:
             pass
         return self.get_fallback()
 
@@ -77,6 +77,8 @@ class DataVarsBuilderLinux(linux.LinuxDataVars):
                     env.VariableClEnvPath(),
                     env.VariableClEbuildPhase(),
                     update.VariableClUpdateUsetagSet(section="update"),
+                    update.VariableClUpdateGpgForce(section="update"),
+                    update.VariableClUpdateGpgKeys(section="update"),
                     update.VariableClUpdateBinhostBase(section="update"),
                     update.VariableClUpdateBinhostBaseSet(section="update"),
                     update.VariableClUpdateWithBdepsSet(section="update"),
@@ -102,8 +104,9 @@ class DataVarsBuilderLinux(linux.LinuxDataVars):
                     update.VariableClUpdateBinhostTimeout(section="update"),
                     update.VariableClUpdateBinhostList(section="update"),
                     update.VariableClUpdateBinhostUnstableList(section="update"),
-                    update.VariableClUpdateBinhostStableSet(section="update"),
+                    update.VariableClUpdateBinhostData(section="update"),
                     update.VariableClUpdateBinhostStableOptSet(section="update"),
+                    update.VariableClUpdateBinhostStableSet(section="update"),
                     update.VariableClUpdateBinhostTimestampPath(
                         section="update"),
                     update.VariableClUpdateBinhostRevisionPath(
@@ -153,6 +156,24 @@ class VariableClBuilderBinarySet(ReadonlyVariable):
                 return "on"
         return "off"
 
+class VariableClBuilderGpgForce(BuilderLinux, update.VariableClUpdateGpgForce):
+    """
+    Использовать GPG проверку
+    """
+    variable = "cl_update_gpg_force"
+    mode = Variable.Writable
+
+    def get_fallback(self):
+        return "force"
+
+class VariableClBuilderBinhost(BuilderLinux, update.VariableClUpdateBinhost):
+    """
+    Принудительное действие с eix-update
+    """
+    variable = "cl_update_binhost"
+
+    def get_fallback(self):
+        return ""
 
 class VariableClBuilderUsetagSet(ReadonlyVariable):
     """
@@ -179,9 +200,6 @@ class VariableClBuilderLinuxDatavars(ReadonlyVariable):
     def prepare_vars(self, dvbl):
         dvbl['cl_update_binhost_recheck_set'] = \
             self.Get('update.cl_update_binhost_recheck_set')
-        dvbl['cl_update_binhost_stable_opt_set'] = \
-            self.Get('cl_builder_binhost_stable_set')
-        dvbl['cl_update_binhost_stable_set'] = "off"
         if self.Get('cl_action') not in (
                 Actions.Update, Actions.ChangeProfile) or \
                 not self.GetBool('cl_builder_binhost_scan_set'):
@@ -323,6 +341,48 @@ class VariableOsBuilderLinuxSubname(BuilderLinux):
     def humanReadable(self):
         return self.Get() or _("no")
 
+class VariableClBuilderGpgKeys(BuilderLinux):
+    """
+    GPG keys
+    """
+    type = Variable.Types.List
+    variable = "cl_update_gpg_keys"
+
+    def get_fallback(self):
+        return []
+
+class VariableClBuilderBinhostRevisionPath(BuilderLinux):
+    """
+    Путь до revision файлов
+    """
+    variable = "cl_update_binhost_revision_path"
+    type = Variable.Types.List
+
+    def get_fallback(self):
+        value = [
+            "grp/ini.env"
+    ]
+
+class VariableClBuilderBinhostTimestampPath(BuilderLinux):
+    """
+    Путь до файла timestamp
+    """
+    variable = "cl_update_binhost_timestamp_path"
+    type = Variable.Types.List
+
+    def get_fallback(self):
+        value = "timestamp"
+
+
+class VariableClBuilderLastTimestamp(BuilderLinux):
+    """
+    Путь до файла timestamp
+    """
+    variable = "cl_update_last_timestamp"
+
+    def get_fallback(self):
+        value = "0"
+
 
 class VariableClBuilderPortdirOverlay(ReadonlyVariable):
     """
@@ -468,3 +528,10 @@ class VariableClBuilderBinhostBase(ReadonlyVariable):
         if dv:
             return dv.Get('cl_update_binhost_base')
         return ""
+
+class VariableClBuilderPortageBinhost(ReadonlyVariable):
+    """
+    Прописываемый в /etc/portage/make.conf/binhost репозиторий
+    """
+    value_format = "{update.cl_update_binhost}/grp/{builder.os_builder_arch_machine}"
+
